@@ -2,17 +2,25 @@
  
 import sys
 import os
-
-from subprocess import call
 import subprocess
 import shlex
 
-from build_scenarist.utility import splitTargetCallToNameAndParams
-from build_scenarist.config import bcolors, global_vars, defaultScenarioNameEnding, defaultScenarioDir
-from build_scenarist.runner import runTargets
+from subprocess import call
 
-def runTarget(targetCall):
-    runTargets([targetCall])
+from . utility import splitTargetCallToNameAndParams
+from . config import bcolors, global_vars, defaultScenarioNameEnding, defaultScenarioDir
+from . runner import runTargets
+
+def runTarget(targetCall, scenarios = "*", scenarioDir=defaultScenarioDir):
+    if scenarios != "*":
+        scenariosFullPathes = []
+        for scenarioName in scenarios:
+            path = os.path.join(scenarioDir, scenarioName)
+            if os.path.isfile(path):
+                scenariosFullPathes.append(path)
+        scenarios = scenariosFullPathes
+
+    runTargets([targetCall], scenarios)
 
 def runShell(cmd, fallAtFail=True):
     sys.stdout.write("\n" + bcolors.HEADER + "shell: " + bcolors.ENDC + "\n")
